@@ -13,6 +13,7 @@
 # limitations under the License.
 
 """Tools for representing JavaScript code in BSON."""
+from __future__ import annotations
 
 from collections.abc import Mapping as _Mapping
 from typing import Any, Mapping, Optional, Type, Union
@@ -22,8 +23,8 @@ class Code(str):
     """BSON's JavaScript code type.
 
     Raises :class:`TypeError` if `code` is not an instance of
-    :class:`basestring` (:class:`str` in python 3) or `scope`
-    is not ``None`` or an instance of :class:`dict`.
+    :class:`str` or `scope` is not ``None`` or an instance
+    of :class:`dict`.
 
     Scope variables can be set by passing a dictionary as the `scope`
     argument or by using keyword arguments. If a variable is set as a
@@ -50,11 +51,11 @@ class Code(str):
     __scope: Union[Mapping[str, Any], None]
 
     def __new__(
-        cls: Type["Code"],
-        code: Union[str, "Code"],
+        cls: Type[Code],
+        code: Union[str, Code],
         scope: Optional[Mapping[str, Any]] = None,
         **kwargs: Any,
-    ) -> "Code":
+    ) -> Code:
         if not isinstance(code, str):
             raise TypeError("code must be an instance of str")
 
@@ -86,7 +87,7 @@ class Code(str):
         """Scope dictionary for this instance or ``None``."""
         return self.__scope
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"Code({str.__repr__(self)}, {self.__scope!r})"
 
     def __eq__(self, other: Any) -> bool:
